@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict
+from typing import Any, Dict, Mapping
 
 from .literals import (
     ChangesetStatusType,
@@ -73,15 +73,15 @@ _RequiredCreateChangesetRequestRequestTypeDef = TypedDict(
         "datasetId": str,
         "changeType": ChangeTypeType,
         "sourceType": Literal["S3"],
-        "sourceParams": Dict[str, str],
+        "sourceParams": Mapping[str, str],
     },
 )
 _OptionalCreateChangesetRequestRequestTypeDef = TypedDict(
     "_OptionalCreateChangesetRequestRequestTypeDef",
     {
         "formatType": FormatTypeType,
-        "formatParams": Dict[str, str],
-        "tags": Dict[str, str],
+        "formatParams": Mapping[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
